import interact from 'interactjs';
import * as React from 'react';
import { useRef, useEffect } from 'react';

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

var options = ['draggable', 'resizable', 'gesturable', 'dropzone'];
var events = [// Interact Events
'DragStart', 'DragMove', 'DragInertiaStart', 'DragEnd', 'ResizeStart', 'ResizeMove', 'ResizeInertiaStart', 'ResizeEnd', 'GestureStart', 'GestureMove', 'GestureEnd', // Drop Events
'DropActivate', 'DropdEactivate', 'DragEnter', 'DragLeave', 'DropMove', 'Drop', // Pointer Events
'Down', 'Move', 'Up', 'Cancel', 'Tap', 'DoubleTap', 'Hold'];

var reactable = function reactable(BaseComponent) {
  return function (props) {
    var interactable = useRef(null);
    var node = useRef(); //Create interactable

    useEffect(function () {
      if (!node.current) {
        console.error(' you should apply getRef props in the dom element'); // eslint-disable-line

        return;
      }

      interactable.current = interact(node.current);
      return function () {
        return interactable.current.unset();
      };
    }, []); //Set options

    useEffect(function () {
      if (interactable.current) {
        options.forEach(function (option) {
          if (option in props) {
            interactable.current[option](props[option]);
          }
        });
      } // eslint-disable-next-line react-hooks/exhaustive-deps

    }, []); // "props" should be added to the update array. However, this causes infinite rerenders.
    //Set handlers

    useEffect(function () {
      if (interactable.current) {
        events.forEach(function (event) {
          var handler = props["on" + event];

          if (typeof handler === 'function') {
            interactable.current.on(event.toLowerCase(), handler);
          }
        });
        return function () {
          events.forEach(function (event) {
            var handler = props["on" + event];

            if (typeof handler === 'function') {
              interactable.current.off(event.toLowerCase(), handler);
            }
          });
        };
      }
    }, [props]);

    var baseProps = function baseProps(props) {
      var baseProps = _extends({}, props);

      options.forEach(function (option) {
        return delete baseProps[option];
      });
      events.forEach(function (event) {
        return delete baseProps["on" + event];
      });
      return baseProps;
    };

    return React.createElement(BaseComponent, _extends({}, baseProps(props), {
      getRef: node
    }));
  };
};

export { reactable as default };
//# sourceMappingURL=index.m.js.map
