import interact from 'interactjs';
import * as React from 'react';
import { useRef, useEffect } from 'react';

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

const options = ['draggable', 'resizable', 'gesturable', 'dropzone'];
const events = [// Interact Events
'DragStart', 'DragMove', 'DragInertiaStart', 'DragEnd', 'ResizeStart', 'ResizeMove', 'ResizeInertiaStart', 'ResizeEnd', 'GestureStart', 'GestureMove', 'GestureEnd', // Drop Events
'DropActivate', 'DropdEactivate', 'DragEnter', 'DragLeave', 'DropMove', 'Drop', // Pointer Events
'Down', 'Move', 'Up', 'Cancel', 'Tap', 'DoubleTap', 'Hold'];

const reactable = BaseComponent => props => {
  const interactable = useRef(null);
  const node = useRef(); //Create interactable

  useEffect(() => {
    if (!node.current) {
      console.error(' you should apply getRef props in the dom element'); // eslint-disable-line

      return;
    }

    interactable.current = interact(node.current);
    return () => interactable.current.unset();
  }, []); //Set options

  useEffect(() => {
    if (interactable.current) {
      options.forEach(option => {
        if (option in props) {
          interactable.current[option](props[option]);
        }
      });
    } // eslint-disable-next-line react-hooks/exhaustive-deps

  }, []); // "props" should be added to the update array. However, this causes infinite rerenders.
  //Set handlers

  useEffect(() => {
    if (interactable.current) {
      events.forEach(event => {
        const handler = props[`on${event}`];

        if (typeof handler === 'function') {
          interactable.current.on(event.toLowerCase(), handler);
        }
      });
      return () => {
        events.forEach(event => {
          const handler = props[`on${event}`];

          if (typeof handler === 'function') {
            interactable.current.off(event.toLowerCase(), handler);
          }
        });
      };
    }
  }, [props]);

  const baseProps = props => {
    const baseProps = _extends({}, props);

    options.forEach(option => delete baseProps[option]);
    events.forEach(event => delete baseProps[`on${event}`]);
    return baseProps;
  };

  return React.createElement(BaseComponent, _extends({}, baseProps(props), {
    getRef: node
  }));
};

export { reactable as default };
//# sourceMappingURL=index.modern.js.map
